@@ -21,6 +21,8 @@
 
 int main(int argc, char *argv[])
 {
+    // Fixes blurry icons with fractional scaling
+    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain("kollision");
